pkgs: {
	enable = true;
	profiles = { nixos = {
		name = "NixOS Profile";
		settings = {
			"media.ffmpeg.vaapi.enabled" = true;
			"browser.startup.homepage" = "https://ipfs.io/ipfs/QmcnP6Fa2cs8SMLAMC12caF1pFoso4ZKU8FLKagFtKGfa1";
			"browser.cache.disk.capacity" = 536870912; # 1 GiB
			"extensions.pocket.enabled" = false;
			"browser.eme.ui.enabled" = false; # DRM popup
			"image.jxl.enabled" = true;
			"xpinstall.signatures.required" = true;

			"browser.search.suggest.enabled" = false;
			"browser.urlbar.suggest.quicksuggest.sponsored" = false;

			"browser.aboutConfig.showWarning" = false;

			# Privacy Shit
			"privacy.firstparty.isolate" = true;
			"privacy.trackingprotection.enabled" = true;
			"media.peerconnection.ice.default_address_only" = true;
			"toolkit.telemetry.log.level" = "Fatal";
			"toolkit.telemetry.server" = "";
			"toolkit.telemetry.shutdownPingSender.enabled" = false;
			"toolkit.telemetry.newProfilePing.enabled" = false;
			"toolkit.telemetry.prioping.enabled" = true;
			"datareporting.healthreport.uploadEnabled" = false;
			"toolkit.telemetry.enabled" = false;
			"toolkit.telemetry.archive.enabled" = false;
			"toolkit.telemetry.unified" = false;
			"toolkit.telemetry.pioneer-new-studies-available" = false;
			# https://support.mozilla.org/en-US/kb/global-privacy-control
			"privacy.globalprivacycontrol.enabled" = true;
			# https://support.mozilla.org/en-US/kb/how-do-i-turn-do-not-track-feature
			"privacy.donottrackheader.enabled" = true;
		};
		search.force = true;
		search.default = "DuckDuckGo";
		search.engines = {
			"YouTube" = {
				urls = [{
					template = "https://youtube.com/results";
					params = [
						{name = "search_query"; value = "{searchTerms}";}
						{name = "page"; value = "{startPage}";}
					];
				}];
				iconUpdateURL = "https://www.youtube.com/favicon.ico";
				updateInterval = 7 * 24 * 60 * 60 * 1000; # every week
				definedAliases = [ "!yt" ];
			};
			"Wiktionary" = {
				urls = [{
					template = "https://en.wiktionary.org/w/index.php";
					params = [
						{name = "search"; value = "{searchTerms}";}
						{name = "page"; value = "{startPage}";}
					];
				}];
				iconUpdateURL = "https://en.wiktionary.org/static/favicon/wiktionary/en.ico";
				updateInterval = 30 * 24 * 60 * 60 * 1000; # every month
				definedAliases = [ "!wt" ];
			};
			"ArchWiki" = {
				urls = [{
					template = "https://wiki.archlinux.org/index.php";
					params = [
						{name = "search"; value = "{searchTerms}";}
						{name = "title"; value = "Special:Search";}
					];
				}];
				iconUpdateURL = "https://wiki.archlinux.org/favicon.ico";
				updateInterval = 7 * 24 * 60 * 60 * 1000; # every week
				definedAliases = [ "!a" ];
			};
			"NixOS Wiki" = {
				urls = [{ template = "https://nixos.wiki/index.php?search={searchTerms}"; }];
				iconUpdateURL = "https://nixos.wiki/favicon.png";
				updateInterval = 7 * 24 * 60 * 60 * 1000; # every week
				definedAliases = [ "!nix" ];
			};
			"Anna's Archive" = {
				urls = [
					{
						template = "https://annas-archive.org/search";
						params = [
							{name = "q"; value = "{searchTerms}";}
						];
					}
				];
				iconUpdateURL = "https://annas-archive.org/favicon.ico";
				updateInterval = 7 * 24 * 60 * 60 * 1000; # every week
				definedAliases = [ "!aa" ];
			};
			"GitHub" = {
				urls = [
					{
						template = "https://github.com/search";
						params = [
							{name = "q"; value = "{searchTerms}";}
						];
					}
				];
				iconUpdateURL = "https://github.com/favicon.ico";
				updateInterval = 7 * 24 * 60 * 60 * 1000; # every week
				definedAliases = [ "!gh" ];
			};
			"Semantic Scholar" = {
				urls = [
					{
						template = "https://www.semanticscholar.org/search";
						params = [
							{name = "q"; value = "{searchTerms}";}
						];
					}
				];
				iconUpdateURL = "https://cdn.semanticscholar.org/445569b6ca9ba36c/img/darkmode/favicon-196x196.png";
				updateInterval = 7 * 24 * 60 * 60 * 1000; # every week
				definedAliases = [ "!s2" ];
			};
			"Minecraft Wiki" = {
				urls = [{
					template = "https://minecraft.wiki/";
					params = [
						{name = "search"; value = "{searchTerms}";}
					];
				}];
				iconUpdateURL = "https://minecraft.wiki/favicon.ico";
				updateInterval = 7 * 24 * 60 * 60 * 1000; # every week
				definedAliases = [ "!mc" ];
			};
			"Wikipedia (en)".metaData.alias = "!w";
			"Google".metaData.alias = "!g";
			"Bing".metaData.hidden = true;
		};
	};};
}